Crate dragoonfri

Crate dragoonfri 

FRI - Fast Reed-solomon Interactive oracle proof of proximity

Re-exports

pub use commit::FriCommitments;

Modules

algorithms
This module contains implementations of trait rs_merkle::Hasher for other algorithms than Sha2-256 and Sha2-384, which are already provided by rs_merkle.
commit
Implementation of the COMMIT phase of the FRI algorithm
folding
Takes care of folding the polynomials to reduce their degrees
frida
Implementation of FRIDA scheme above FRI https://eprint.iacr.org/2024/248.pdf
interpolation
Implements Lagrange’s polynomial interpolation as defined in Alin Bostan et al. 2018
rng
Related to random things
utils

Macros

dynamic_folding_factor
Calls a FRI function with a folding factor that is not known at compile time. The following examples assume the folding factor is contained in variable factor. The identifier FACTOR can be changed to any valid identifier. By convention, it should be SCREAMING_SNAKE_CASE.

Structs

FriProof
A FRI proof.

Enums

VerifyError
errors that can happen when verifying a FRI proof

Functions

build_proof
Constructs a FRI proof by making queries to the commitments.
commit_polynomial
Commits the polynomial according to FRI algorithm.