FriCommitments

Struct FriCommitments 

pub struct FriCommitments<const N: usize, F, H: Hasher> { /* private fields */ }
Result of a polynomial folding (FRI COMMIT phase).

Use crate::commit_polynomial to create a FriCommitments from a polynomial in coefficient form, or FriCommitments::new to create it from the evaluations directly.

Use crate::build_proof to get an actual FRI proof from a FriCommitments.

Implementations

Source

impl<const N: usize, F: FftField, H: Hasher> FriCommitments<N, F, H>

pub fn new<R>( evaluations: Vec<F>, rng: R, blowup_factor: usize, remainder_degree_plus_one: usize, ) -> Self
where R: ReseedableRng<Seed = H::Hash>,

Commits the polynomial according to FRI algorithm.

  • evaluations is the list of evaluations of the polynomial on the n-th roots of unity (where n = evaluations.len()).

See crate::commit_polynomial for information about the other parameters.

Panics

This may either panic or have unspecified behaviour if remainder_degree_plus_one is inconsistent with the degree-bound of the polynomial and the folding factor, or if F does not contain a subgroup of size evaluations.len().